@@ -5,12 +5,12 @@
 #################    - ukrywanie aplikacji, updateminiatures przy aktywacji okna
 #- poprawa przyblizenia
 #- poprawa wykrywania orientacji
-# - poprawic indeksowanie w show!!!!!!!!!!!!
-#- wczytywanie qimagereaderem w innym watku, na finish ustaw pixmape
+#-
+#- 
 import sys
 from PySide.QtCore import QThread, QEvent, QRect, QTimer, QCoreApplication, Qt, QSize
 from PySide import QtMaemo5
-from PySide.QtGui import QImageReader, QWidget, QImage, QMessageBox, QMenu, QPushButton, QApplication, QFileDialog, QInputDialog, QSizePolicy, QScrollArea, QIcon, QGridLayout, QAction, QPalette, QToolButton, QMainWindow, QPixmap, QLabel
+from PySide.QtGui import QImageReader, QMatrix, QToolBar, QWidget, QImage, QMessageBox, QMenu, QPushButton, QApplication, QFileDialog, QInputDialog, QSizePolicy, QScrollArea, QIcon, QGridLayout, QAction, QPalette, QToolButton, QMainWindow, QPixmap, QLabel
 import os, md5, math
 import dbus
 import osso
@@ -122,12 +122,18 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
   pixmap = 0
   pix = None
   dbus = None
+  toolbar = None
+  tempPix = None
+  rotateFinish = 0
   def __init__(self, dbus, licz, index,parent=None):
     super(PixWindow, self).__init__()
+    self.setAttribute(Qt.WA_Maemo5AutoOrientation)
     self.licz = licz
     self.index = index
     self.dbus = dbus
     self.grabMouse()
+    self.rm = QMatrix()
+    self.rotateFlag = 0
     self.loadPix = LoadPixThread(self)
     self.loadPix.finished.connect(self.loadBetter)
     self.timer = QTimer()
@@ -143,17 +149,104 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
     self.imageLabel.setScaledContents(True)
     self.scrollArea.setBackgroundRole(QPalette.Dark)
     self.setCentralWidget(self.scrollArea)
+    self.menuPix = QToolButton(self)
+    self.menuPix.released.connect(self.showTools)
+    
+    self.generalDelete = QIcon("/usr/share/icons/hicolor/48x48/hildon/camera_delete.png")
+    self.generalStop = QIcon("/usr/share/icons/hicolor/48x48/hildon/general_stop.png")
+    self.toolbar = QToolBar(self)
+    self.toolbar.setGeometry(self.width()/2-233, self.height()+80 , 466, 80)
+    self.toolbar.setStyleSheet("background-color: rgb(0,0,0);")
+    self.prevBtn = QToolButton()
+    self.prevBtn.setIcon(QIcon("/usr/share/icons/hicolor/48x48/hildon/general_back.png"))
+    self.prevBtn.clicked.connect(self.prevPix)
+    self.toolbar.addWidget(self.prevBtn)
+    self.toolbar.addSeparator()
+    self.toolbar.addSeparator()
+    self.deleteBtn = QToolButton()
+    self.deleteBtn.setIcon(self.generalDelete)
+    self.deleteBtn.clicked.connect(self.markToDelete)
+    self.toolbar.addWidget(self.deleteBtn)
+    self.closeBtn = QToolButton()
+    self.closeBtn.setIcon(QIcon("/usr/share/icons/hicolor/48x48/hildon/general_close.png"))
+    self.closeBtn.clicked.connect(self.close)
+    self.toolbar.addWidget(self.closeBtn)
+    self.hideBtn = QToolButton()
+    self.hideBtn.setIcon(QIcon("/usr/share/icons/hicolor/48x48/hildon/rss_reader_move_down.png"))
+    self.hideBtn.clicked.connect(self.hideTools)
+    self.toolbar.addWidget(self.hideBtn)
+    self.rotateBtn = QToolButton()
+    self.rotateBtn.setIcon(QIcon("/usr/share/icons/hicolor/48x48/hildon/imageviewer_rotate.png"))
+    self.rotateBtn.clicked.connect(self.rotatePix)
+    self.toolbar.addWidget(self.rotateBtn)
+    self.fitBtn = QToolButton()
+    self.fitBtn.setIcon(QIcon("/usr/share/icons/hicolor/48x48/hildon/sketch_square.png"))
+    self.fitBtn.clicked.connect(self.fitPix)
+    self.toolbar.addWidget(self.fitBtn)
+    self.toolbar.addSeparator()
+    self.toolbar.addSeparator()
+    self.nextBtn = QToolButton()
+    self.nextBtn.setIcon(QIcon("/usr/share/icons/hicolor/48x48/hildon/general_forward.png"))
+    self.nextBtn.clicked.connect(self.nextPix)
+    self.toolbar.addWidget(self.nextBtn)
+    
+  def showTools(self):
+    self.menuPix.setDisabled(True)
+    i = self.height()+80
+    while i > self.height()-80:
+      self.toolbar.move(self.width()/2-233, i)
+      i-=10
+      QApplication.processEvents()
+       
+  def hideTools(self):
+    self.menuPix.setDisabled(False)
+    i = self.height()-80
+    while i < self.height()+80:
+      self.toolbar.move(self.width()/2-233, i)
+      i+=10
+      QApplication.processEvents()
+      
+  def markToDelete(self):
+    print "marktodelete"
+    self.parent.miniatures[self.index].markToDelete()
+    if self.parent.miniatures[self.index].toDelete == "yes":
+      box = QtMaemo5.QMaemo5InformationBox()
+      box.information(self, "<b><font color='black'>"+self.licz[self.index]+" is marked to delete", 500)
+      box.show()  
+    else:
+      box = QtMaemo5.QMaemo5InformationBox()
+      box.information(self, "<b><font color='black'>"+self.licz[self.index]+" is unmarked", 500)
+      box.show()  
+      
+    
+  def rotatePix(self):
+    if self.rotateFlag == 4:
+      self.rotateFlag = 0
+    pixmap = self.imageLabel.pixmap() # we took rotated pixmap so we will rotate it only for 90 deg
+    rm = QMatrix()
+    rm.rotate(90) 
+    self.imageLabel.setPixmap(pixmap.transformed(rm))
+    self.rotateFlag+=1
+    self.fitPix()
     
   def timeout(self):
-#    self.loadPix = LoadPixThread(self)
-#    self.loadPix.finished.connect(self.loadBetter)
-    
     self.loadPix.start()
 
   def loadBetter(self):
     if self.timer.isActive():
       self.timer.stop()    
-    self.imageLabel.setPixmap(QPixmap().fromImage(self.pix))
+    pix = QPixmap().fromImage(self.pix)
+    rm = QMatrix()
+    if self.rotateFlag == 0:
+      rm.rotate(0)
+    elif self.rotateFlag == 1:
+      rm.rotate(90)
+    elif self.rotateFlag == 2:
+      rm.rotate(180)
+    elif self.rotateFlag == 3:
+      rm.rotate(270)
+#    self.imageLabel.setPixmap(pix)
+    self.imageLabel.setPixmap(pix.transformed(rm))
     self.loadPix.wait()
 #    self.fitPix()
     
@@ -249,16 +342,16 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
     self.dbus.exit_app_view("MaePyGallery - minimalize")
     
   def nextPix(self):
-    self.blockSignals(True)  
-    #    print dir(QThread)
+    self.blockSignals(True)
     self.loadBetterFlag = 0
+    self.rotateFlag = 0 #reseting rotateFlag
     if self.timer.isActive():
       self.timer.stop()
     if self.index+1 == len(self.licz):
       self.index = 0
     else:
       self.index = self.index+1
-      
+    
     self.reader.setFileName(self.licz[self.index])
     pixSize = self.reader.size()
     pixSize.scale(800*0.8,480*0.8, Qt.KeepAspectRatio)
@@ -276,19 +369,29 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
       
     self.imageLabel.setPixmap(pix)
     self.fitPix()
+    QApplication.processEvents()
     self.setWindowTitle(str(self.licz[self.index]))
     self.blockSignals(False)    
-        
-  def prevPix(self):
+    self.styleDel()
+    
+  def styleDel(self):
+    if self.parent.miniatures[self.index].toDelete == "yes":
+      box = QtMaemo5.QMaemo5InformationBox()
+      box.information(self, "<b><font color='black'>"+self.licz[self.index]+" is marked to delete", 600)
+      box.show()    
+    else:
+      pass
+      
+  def prevPix(self):  
     self.blockSignals(True)
     self.loadBetterFlag = 0
+    self.rotateFlag = 0 #reseting rotateFlag
     if self.timer.isActive():
       self.timer.stop()
     if self.index == 0:
       self.index = len(self.licz)-1
     else:
       self.index = self.index-1
-
     self.reader.setFileName(self.licz[self.index])  
     pixSize = self.reader.size()
     pixSize.scale(800*0.8,480*0.8, Qt.KeepAspectRatio)
@@ -304,15 +407,21 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
       QApplication.processEvents()
     self.imageLabel.setPixmap(pix)
     self.fitPix()
+    QApplication.processEvents()
     self.setWindowTitle(str(self.licz[self.index]))
     self.blockSignals(False)
+    self.styleDel()
 
   def mouseDoubleClickEvent(self, e):  #powiekszanie obrazka w nacisnietym miejscu
     if self.flag == 0:    
       if self.parent.checkOrientation() == "portrait": #self.imageLabel.height() < self.height(): #operowanie na podstawie wartosci scrollbara
         #skalowanie dla trybu portretowego
-        p = QPixmap(self.imageLabel.pixmap()).scaledToHeight(800)
-        self.imageLabel.resize(p.width(), p.height()-10)
+        if self.imageLabel.width() > self.imageLabel.height():
+          p = QPixmap(self.imageLabel.pixmap()).scaledToHeight(800)
+          self.imageLabel.resize(p.width(), p.height()-10)
+        else:
+          p = QPixmap(self.imageLabel.pixmap()).scaledToWidth(self.width()*2)
+          self.imageLabel.resize(p.width(), p.height()-10)  
         self.scrollArea.move(0,0)
         tempV = p.height()/2        
         tempH = e.x()
@@ -329,13 +438,18 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
 #      self.scrollArea.move(0, (self.height()/2)-(self.imageLabel.height()/2))      
       elif self.parent.checkOrientation() == "landscape": 
         #skalowanie dla trybu poziomego
-        self.imageLabel.resize(self.imageLabel.width()*2,self.imageLabel.height()*2)
-#        self.imageLabel.pixmap().scaledToWidth(self.imageLabel.width()*2)
-#        if self.scrollArea.horizontalScrollBar().value() == 0 and self.scrollArea.verticalScrollBar().value() == 0:
+        if self.imageLabel.width() < self.imageLabel.height(): 
+          p = QPixmap(self.imageLabel.pixmap()).scaledToWidth(self.width())
+          self.imageLabel.resize(p.width()-8, p.height())
+        else:
+          self.imageLabel.resize(self.imageLabel.width()*2,self.imageLabel.height()*2)
+          self.imageLabel.pixmap().scaledToHeight(self.imageLabel.height()*2)
+       
+        if self.scrollArea.horizontalScrollBar().value() == 0 and self.scrollArea.verticalScrollBar().value() == 0:
           #scrollbary sa == 0
-        self.scrollArea.horizontalScrollBar().setValue(e.x())
-        self.scrollArea.verticalScrollBar().setValue(e.y())
-        self.scrollArea.move(0,0)  
+          self.scrollArea.horizontalScrollBar().setValue(e.x())
+          self.scrollArea.verticalScrollBar().setValue(e.y())
+          self.scrollArea.move(0,0)  
         if self.loadBetterFlag == 0:
           self.timer.start(1)
           box = QtMaemo5.QMaemo5InformationBox()
@@ -373,7 +487,7 @@ class Main(QMainWindow): ################## Main Class ##################
   
   def __init__(self, size, parent=None):
     super(Main, self).__init__()
-    
+    self.setAttribute(Qt.WA_Maemo5AutoOrientation)
     self.osso_c = osso.Context("maepygallery", "0.1.3", False)
     self.reader = QImageReader()
     self.setWindowTitle("MaePyGallery - " + self.dirPix)
@@ -646,6 +760,7 @@ class Main(QMainWindow): ################## Main Class ##################
       self.pix = PixWindow(self.dbus, self.licz, index, self)
     self.pix.flag = 0
     self.pix.loadBetterFlag = 0
+    self.pix.rotateFlag = 0
     self.pix.index = index
     self.pix.setStyleSheet("QToolButton { background-color: rgba(0,0,0,0%); }")
     self.pix.setWindowTitle(str(self.licz[index]))
@@ -663,9 +778,7 @@ class Main(QMainWindow): ################## Main Class ##################
     self.pix.prevPixBtn = QToolButton(self.pix)
     self.pix.prevPixBtn.setGeometry(0,0,50,self.height()+50)
     self.pix.prevPixBtn.released.connect(self.pix.prevPix)
-    self.pix.restorePixSize = QToolButton(self.pix)
-    self.pix.restorePixSize.setGeometry(0,self.height()+10,self.width(), 50)
-    self.pix.restorePixSize.released.connect(self.pix.fitPix)
+    self.pix.menuPix.setGeometry(0,self.height()+10,self.width(), 50)
     self.pix.nextPixBtn = QToolButton(self.pix)
     self.pix.nextPixBtn.setGeometry(self.width()-50,0,50, self.height()+50)
     self.pix.nextPixBtn.released.connect(self.pix.nextPix)
@@ -679,7 +792,9 @@ class Main(QMainWindow): ################## Main Class ##################
     QApplication.processEvents()
     self.pix.update()
     self.pix.fitPix()
-  
+    self.pix.hideTools()
+    QApplication.processEvents()
+    self.pix.fitPix()
   def options(self):
     i=0
     while i > -self.width():
@@ -713,8 +828,8 @@ class Main(QMainWindow): ################## Main Class ##################
   def helpDialog(self):
     text = """Interface of second window: <br> Left border button - previous picture <br> 
     Right border button - next picture <br> 
-    Upper border button - restore view <br>
-    Bottom border button - minimalize window <br>
+    Upper border button - minimalize window <br>
+    Bottom border button - popup toolbar <br>
     DoublePress - zoom in <br>
     Keys:<br>
       Z - zoom in<br>
@@ -760,10 +875,12 @@ class Main(QMainWindow): ################## Main Class ##################
     #obrot przyciskow w drugim oknie przegladania zdjec
     if self.pix != None:
       if self.pix.prevPixBtn != None:
+        self.pix.hideTools()
         self.pix.prevPixBtn.setGeometry(0,0,30,self.height()+30)
-        self.pix.restorePixSize.setGeometry(0,self.height()+10,self.width(), 50)
+        self.pix.menuPix.setGeometry(0,self.height()+10,self.width(), 50)
         self.pix.nextPixBtn.setGeometry(self.width()-30,0,30, self.height()+30)
         self.pix.minimalizeBtn.setGeometry(0,0,self.width(),50)
+        self.pix.toolbar.setGeometry(self.width()/2-233, self.height()+80 , 466, 80)
         self.pix.fitPix()
     self.label = QLabel()
     self.label.setBackgroundRole(QPalette.Base)
@@ -839,6 +956,8 @@ class Main(QMainWindow): ################## Main Class ##################
     self.scrollArea.verticalScrollBar().setValue(self.adjustedHeight)
 
   def deleteSelected(self):
+    if self.pix != None:
+      self.pix.close()
     self.setWindowTitle("Deleting...")
     deleteCount = 0    
     for i in self.miniatures:
